@@ -268,6 +268,11 @@ Only relevant when `doom-modeline-time-analogue-clock' is non-nil, which see."
   :type 'number
   :group 'doom-modeline)
 
+(defcustom doom-modeline-unicode-number t
+  "Whether to use unicode numbers."
+  :type 'boolean
+  :group 'doom-modeline)
+
 (defcustom doom-modeline-unicode-fallback nil
   "Whether to use unicode as a fallback (instead of ASCII) when not using icons."
   :type 'boolean
@@ -1120,6 +1125,7 @@ Which are not explicitly listed in `doom-modeline-vcs-state-faces-alist'."
   '((t (:inherit doom-modeline-warning :slant italic :height 0.9)))
   "Face for compilation progress."
   :group 'doom-modeline-faces)
+
 
 ;;
 ;; Externals
@@ -1237,8 +1243,8 @@ used as an advice to window creation functions."
 
 (defun doom-modeline-set-selected-window (&rest _)
   "Set `doom-modeline-current-window' appropriately."
-  (let ((win (doom-modeline--selected-window)))
-    (setq doom-modeline-current-window
+  (setq doom-modeline-current-window
+        (let ((win (doom-modeline--selected-window)))
           (if (minibuffer-window-active-p win)
               (minibuffer-selected-window)
             win))))
@@ -1247,51 +1253,12 @@ used as an advice to window creation functions."
   "Unset `doom-modeline-current-window' appropriately."
   (setq doom-modeline-current-window nil))
 
-(add-hook 'pre-redisplay-functions #'doom-modeline-set-selected-window)
+(defun doom-modeline-focus-change (&rest _)
+  "Focus change."
+  (if (frame-focus-state)
+      (doom-modeline-set-selected-window)
+    (doom-modeline-unset-selected-window)))
 
-;; Ensure modeline is inactive when Emacs is unfocused
-(defvar doom-modeline--remap-faces '(mode-line
-                                     mode-line-active
-                                     mode-line-emphasis
-                                     mode-line-highlight
-                                     mode-line-buffer-id
-                                     doom-modeline
-                                     solaire-mode-line-face
-                                     solaire-mode-line-active-face
-                                     paradox-mode-line-face
-                                     flycheck-color-mode-line-error-face
-                                     flycheck-color-mode-line-warning-face
-                                     flycheck-color-mode-line-info-face
-                                     flycheck-color-mode-line-success-face))
-
-(defvar doom-modeline--remap-face-cookie-alist nil)
-(defun doom-modeline-focus ()
-  "Focus mode-line."
-  (mapc #'face-remap-remove-relative doom-modeline--remap-face-cookie-alist))
-
-(defun doom-modeline-unfocus ()
-  "Unfocus mode-line."
-  (dolist (face doom-modeline--remap-faces)
-    (add-to-list 'doom-modeline--remap-face-cookie-alist
-                 (face-remap-add-relative face 'mode-line-inactive))))
-
-(with-no-warnings
-  (if (boundp 'after-focus-change-function)
-      (progn
-        (defun doom-modeline-focus-change (&rest _)
-          (if (frame-focus-state (frame-parent))
-              (progn
-                (doom-modeline-focus)
-                ;; HACK: pulse after focusing in the frame to refresh the buffer name.
-                ;; @see https://github.com/seagle0128/doom-modeline/issues/591
-                (when (fboundp 'pulse-momentary-highlight-region)
-                  (pulse-momentary-highlight-region 0 0)))
-            (doom-modeline-unfocus)))
-        (advice-add #'handle-switch-frame :after #'doom-modeline-focus-change)
-        (add-function :after after-focus-change-function #'doom-modeline-focus-change))
-    (progn
-      (add-hook 'focus-in-hook #'doom-modeline-focus)
-      (add-hook 'focus-out-hook #'doom-modeline-unfocus))))
 
 
 ;;
@@ -1405,6 +1372,7 @@ If DEFAULT is non-nil, set the default mode-line for all buffers."
             mode-line-format)
           (list "%e" modeline))))
 
+
 ;;
 ;; Helpers
 ;;
@@ -1438,11 +1406,10 @@ If INACTIVE-FACE is nil, `mode-line-inactive' face will be used."
     (or (and (facep inactive-face) `(:inherit (doom-modeline ,inactive-face)))
         '(:inherit (doom-modeline mode-line-inactive)))))
 
-(defun doom-modeline-spc-face ()
-  "Apply `doom-modeline-spc-face-overrides' to `doom-modeline-face'."
-  (append
-   `(:inherit ,(doom-modeline-face))
-   doom-modeline-spc-face-overrides))
+(defun doom-modeline-spc-face (&optional face)
+  "Apply FACE or `doom-modeline-spc-face-overrides' to `doom-modeline-face'."
+  (append `(:inherit ,(doom-modeline-face))
+          (or face doom-modeline-spc-face-overrides)))
 
 (defun doom-modeline-string-pixel-width (str)
   "Return the width of STR in pixels."
@@ -1616,8 +1583,8 @@ respectively."
         'pbm t :foreground color1 :background color2 :ascent 'center)))))
 
 ;; Check whether `window-total-width' is smaller than the limit
-(defun doom-modeline-window-size-change-function (&rest _)
-  "Function for `window-size-change-functions'."
+(defun doom-modeline-window-size-change (&rest _)
+  "Handles while window size is changed."
   (setq doom-modeline--limited-width-p
         (cond
          ((integerp doom-modeline-window-width-limit)
@@ -1625,10 +1592,9 @@ respectively."
          ((floatp doom-modeline-window-width-limit)
           (<= (/ (window-total-width) (frame-width) 1.0)
               doom-modeline-window-width-limit)))))
-
-(add-hook 'after-revert-hook #'doom-modeline-window-size-change-function)
-(add-hook 'buffer-list-update-hook #'doom-modeline-window-size-change-function)
-(add-hook 'window-size-change-functions #'doom-modeline-window-size-change-function)
+(add-hook 'after-revert-hook #'doom-modeline-window-size-change)
+(add-hook 'buffer-list-update-hook #'doom-modeline-window-size-change)
+(add-hook 'window-size-change-functions #'doom-modeline-window-size-change)
 
 (defvar-local doom-modeline--project-root nil)
 (defun doom-modeline--project-root ()
